@@ -4,15 +4,15 @@
 #### Nov- 01-2011
 
 edgesub <-
-function(xxxx, pattern = "-", replacement = "?"){
-	loc <- fmatch(dna = xxxx, pattern = pattern)
+function(x, pattern = "-", replacement = "?"){
+	loc <- fmatch(dna = x, pattern = pattern)
 	newdna <- paste(paste(rep(x = replacement, times = loc), collapse = ""), 
-			  substring(xxxx, loc+1, nchar(xxxx)), sep = "")		  
+			  substring(x, loc+1, nchar(x)), sep = "")		  
 	revdna <- reverse(newdna)		  
 	locrev <- fmatch(revdna, pattern = pattern)		  
 	revdnaresult <- paste(paste(rep(x = replacement, times = locrev), 
 	       collapse = ""), substring(revdna, locrev+1, nchar(newdna)), sep = "")
 	dnaresult <- reverse(revdnaresult)
-	return(dnaresult )
+	return(dnaresult)
 }
 
