@@ -1,3 +1,8 @@
+#### Function supermat as part of R package phylotools
+#### By Jinlong Zhang  <Jinlongzhang01@gmail.com>
+#### Institute of Botany, the Chinese Academy of Sciences, Beijing ,China
+#### Nov- 01-2011
+
 supermat <-
 function(rbcl = NULL, matk = NULL, trn = NULL){
 
@@ -5,12 +10,12 @@ function(rbcl = NULL, matk = NULL, trn = NULL){
 	    stop("at least one phylip file for \"rbcl\" or \"matk\" should be provided")
 	}
 	if(!is.null(rbcl)){
-	    rbcl1 <- read.phy(file.path(getwd(),rbcl))
+	    rbcl1 <- read.phylip(file.path(getwd(),rbcl))
         rbcldat <- phy2dat(x = rbcl1)
-	    rbcldat <- framsub(rbcldat)
+	    rbcldat <- framsub(rbcldat) #Substitute the "-" to "?" on the edges of sequence
 	}
 	if(!is.null(matk)){
-	    matk1 <- read.phy(file.path(getwd(),matk))
+	    matk1 <- read.phylip(file.path(getwd(),matk))
         matkdat <- phy2dat(x = matk1)
 	    matkdat <- framsub(matkdat)
 	}
@@ -36,7 +41,7 @@ function(rbcl = NULL, matk = NULL, trn = NULL){
 	if(!is.null(trn)){
 	    trn2 <- list()
         for(i in 1:length(trn)){
-            trn2[[i]] <- read.phy(file.path(getwd(),trn[i]))
+            trn2[[i]] <- read.phylip(file.path(getwd(),trn[i]))
         }
         trndat <- lapply(trn2, phy2dat)
         trnhdat <- lapply(trndat, framsub)
